# Security Policy

## Supported Versions

The following versions of flock are currently actively receiving security updates:

| Version | Supported          |
| ------- | ------------------ |
| 0.4.x  | :white_check_mark:  |

## Reporting a Vulnerability

We take every report of a vulnerability very seriously, 
and actively encourage our community-members to report 
any issues with the Flock framework as soon as possible
in order to mitigate any potential risks.

To report a vulnerability, you have several options  available:

### 1. Creating a Vulnerability Report (preferred):

We prefer to keep our community informed about potential risks,
and therefore would prefer you open a new [Vulnerability Report](https://github.com/whiteducksoftware/flock/issues/new/choose)
on our Project Board.

This helps keep our community informed about existing risks and allows us to react quickly to a potential
vulnerability in the Flock framework.

### 2. Contacting the Maintainers:

If you prefer to report a vulnerability in private, feel free to contact
any one of the core maintainers of Flock:

- @tilman-sattler
- @AndreRatzenberger
- @swolg


### 3. Official email: (slow)

Alternatively, you can report any vulnerability you encounter to info@whiteduck.de.
Keep in mind however, that this might be slower than Options 1 and 2.
